@@ -1,10 +1,9 @@
 from pymatgen.io.vasp.sets import MPRelaxSet
 from pymatgen.core.structure import Structure
 #from atomate.vasp.workflows.base.core import get_wf
-from atomate.vasp.fireworks.core import  NonSCFFW
 from atomate.vasp.powerups import add_small_gap_multiply, add_stability_check, add_modify_incar, \
     add_wf_metadata, add_common_powerups
-from quantumML.fireworks import StaticFW2D, OptimizeFW2D
+from quantumML.fireworks import StaticFW2D, OptimizeFW2D, NonSCFFW2D
 from atomate.utils.utils import get_wf_from_spec_dict
 
 from atomate.vasp.config import SMALLGAP_KPOINT_MULTIPLY, STABILITY_CHECK, VASP_CMD, DB_FILE, \
@@ -39,8 +38,8 @@ def wf_bandstructure2D(structure, c=None):
     mpr2d = MPRelaxSet(structure, force_gamma=True, user_incar_settings=incar)
     fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
     fws.append(StaticFW2D(parents=fws[0]))
-    fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
-    fws.append(NonSCFFW(parents=fws[1], mode='line'))
+    fws.append(NonSCFFW2D(parents=fws[1], mode='uniform'))
+    fws.append(NonSCFFW2D(parents=fws[1], mode='line'))
     wf = Workflow(fws)
     '''check bandstructure.yaml'''
     '''
